<?php
/**
 * MagazineX customizer class for theme customize options.
 *
 * Class MagazineX_Customizer
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * MagazineX customizer class.
 *
 * Class MagazineX_Customizer
 */
class MagazineX_Customizer {

	/**
	 * Constructor - Sets up customizer.
	 */
	public function __construct() {
		// Load files extending customizer features.
		add_action( 'customize_register', array( $this, 'customize_register' ) );
		// load core customizer files.
		add_action( 'customize_register', array( $this, 'customize_include_core' ), 1 );
		// Load customizer files necessary for registering customizer options.
		add_action( 'customize_register', array( $this, 'customize_include' ), 1 );
		add_action( 'wp_enqueue_scripts', array( $this, 'customizer_dynamic_css' ) );
		add_action( 'enqueue_block_editor_assets', array( $this, 'editor_dynamic_css' ) );
	}

	/**
	 * Include the required files for extending the custom Customize controls.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	public function customize_register( $wp_customize ) {
		// Override default.
		require get_template_directory() . '/inc/customizer/override-defaults.php';
	}

	/**
	 * Load core file for theme customizer framework.
	 */
	public function customize_include_core() {

		// load customizer framework.
		require dirname( __FILE__ ) . '/core/class-magazinex-customizer-framework.php';
		require dirname( __FILE__ ) . '/core/class-magazinex-customize-base-option.php';
	}

	/**
	 * Load the required files for Customize option.
	 */
	public function customize_include() {

		// Selective refresh partial.
		require get_template_directory() . '/inc/customizer/class-magazinex-customizer-partials.php';

		// Register sections and panels.
		require get_template_directory() . '/inc/customizer/class-magazinex-customizer-register-section-panel.php';

		/**
		 * Register options.
		 */
		// Global.
		require get_template_directory() . '/inc/customizer/options/global/class-magazinex-customize-colors-options.php';
		require get_template_directory() . '/inc/customizer/options/global/class-magazinex-customize-sidebar-layout-options.php';

		// Header.
		require get_template_directory() . '/inc/customizer/options/header/class-magazinex-customize-header-bar-options.php';
		require get_template_directory() . '/inc/customizer/options/header/class-magazinex-customize-site-identity-options.php';
		require get_template_directory() . '/inc/customizer/options/header/class-magazinex-customize-primary-header-options.php';
		require get_template_directory() . '/inc/customizer/options/header/class-magazinex-customize-primary-menu-options.php';
		require get_template_directory() . '/inc/customizer/options/header/class-magazinex-customize-page-header-options.php';
		require get_template_directory() . '/inc/customizer/options/header/class-magazinex-customize-drawer-menu-options.php';

		// Content.
		require get_template_directory() . '/inc/customizer/options/content/class-magazinex-customize-blog-options.php';
		require get_template_directory() . '/inc/customizer/options/content/class-magazinex-customize-single-post-options.php';

		// Footer.
		require get_template_directory() . '/inc/customizer/options/footer/class-magazinex-customize-footer-column-options.php';
		require get_template_directory() . '/inc/customizer/options/footer/class-magazinex-customize-footer-bar-options.php';
		require get_template_directory() . '/inc/customizer/options/footer/class-magazinex-customize-scroll-to-top-options.php';
	}

	/**
	 * Adds inline styles.
	 *
	 * @return void
	 */
	public function customizer_dynamic_css() {
		wp_add_inline_style( 'magazinex-style', MagazineX_Dynamic_CSS::get_css() );
	}

	public function editor_dynamic_css() {
		wp_add_inline_style( 'magazinex-block-editor-styles', MagazineX_Dynamic_CSS::magazinex_editor_block_css() );
	}

	/**
	 * Undocumented function.
	 *
	 * @return void
	 */
	public function get_css() {
	}
}

return new MagazineX_Customizer();
