<?php
/**
 * Class to include Blog customize options.
 *
 * Class MagazineX_Customize_Blog_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include Blog customize options.
 *
 * Class MagazineX_Customize_Blog_Options
 */
class MagazineX_Customize_Blog_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$size_choices = MagazineX_Utils::get_image_sizes( array( 'full', 'medium_large', 'large' ) );

		$configs = array(
			array(
				'name'     => 'magazinex_pagination_style_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Pagination', 'magazinex' ),
				'section'  => 'magazinex_blog_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_pagination_style',
				'default'  => 'default',
				'type'     => 'control',
				'control'  => 'select',
				'label'    => esc_html__( 'Style', 'magazinex' ),
				'section'  => 'magazinex_blog_section',
				'priority' => 20,
				'choices'  => array(
					'none'     => esc_html__( 'None', 'magazinex' ),
					'default'  => esc_html__( 'Default', 'magazinex' ),
					'numbered' => esc_html__( 'Numbered', 'magazinex' ),
				),
			),
		);

		$options = array_merge( $options, $configs );

		return $options;
	}

}

return new MagazineX_Customize_Blog_Options();
