<?php
/**
 * Class to include primary header customize options.
 *
 * Class MagazineX_Customize_Primary_Header_Options
 *
 * @package    MagazineX
 * @since      1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

/**
 * Class to include primary header customize options.
 *
 * Class MagazineX_Customize_Primary_Header_Options
 */
class MagazineX_Customize_Primary_Header_Options extends MagazineX_Customize_Base_Option {

	/**
	 * Include customize options.
	 *
	 * @param array                 $options      Customize options provided via the theme.
	 * @param \WP_Customize_Manager $wp_customize Theme Customizer object.
	 *
	 * @return mixed|void Customizer options for registering panels, sections as well as controls.
	 */
	public function register_options( $options, $wp_customize ) {

		$configs = array(

			array(
				'name'     => 'magazinex_primary_header_colors_heading',
				'type'     => 'control',
				'control'  => 'magazinex-title',
				'label'    => esc_html__( 'Colors', 'magazinex' ),
				'section'  => 'magazinex_primary_header_section',
				'priority' => 10,
			),

			array(
				'name'     => 'magazinex_primary_header_background_group',
				'type'     => 'control',
				'control'  => 'magazinex-group',
				'label'    => esc_html__( 'Background', 'magazinex' ),
				'section'  => 'magazinex_primary_header_section',
				'priority' => 20,
			),

			array(
				'name'     => 'magazinex_primary_header_background',
				'default'  => array(
					'background-color'      => '#FFFFFF',
					'background-image'      => '',
					'background-repeat'     => 'repeat',
					'background-position'   => 'center center',
					'background-size'       => 'cover',
					'background-attachment' => 'scroll',
				),
				'type'     => 'sub-control',
				'control'  => 'magazinex-background',
				'section'  => 'magazinex_primary_header_section',
				'parent'   => 'magazinex_primary_header_background_group',
				'priority' => 30,
			),

		);

		$options = array_merge( $options, $configs );

		return $options;
	}
}

return new MagazineX_Customize_Primary_Header_Options();
