<?php
/**
 * Hooks for Footer HTML markups.
 *
 * @package MagazineX
 * @since   1.0.0
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

if ( ! function_exists( 'magazinex_scroll_to_top_markup' ) ) {

	/**
	 * Adds scrol to top markup.
	 *
	 * @return void
	 */
	function magazinex_scroll_to_top_markup() {
		if ( get_theme_mod( 'magazinex_enable_scroll_to_top', 1 ) ) {
			?>
			<a href="#" id="mzx-scroll-to-top" class="mzx-scroll-to-top">
				<?php magazinex_get_icon( 'arrow-up' ); ?>
			</a>
			<?php
		}
	}

	add_action( 'magazinex_scroll_to_top', 'magazinex_scroll_to_top_markup' );
}

if ( ! function_exists( 'magazinex_footer_markup' ) ) {

	/**
	 * Adds scrol to top markup.
	 *
	 * @return void
	 */
	function magazinex_footer_markup() {
		?>

		<footer id="mzx-footer" class="mzx-footer">
			<?php magazinex_footer_columns(); ?>
			<?php magazinex_footer_bar(); ?>
		</footer><!-- #mzx-footer -->
		<?php
	}

	add_action( 'magazinex_footer', 'magazinex_footer_markup' );
}

if ( ! function_exists( 'magazinex_footer_columns_markup' ) ) {

	/**
	 * Adds MagazineX footer columns markup.
	 *
	 * @return void
	 */
	function magazinex_footer_columns_markup() {
		if ( ! is_active_sidebar( 'mzx-footer-col-1' ) && ! is_active_sidebar( 'mzx-footer-col-2' ) && ! is_active_sidebar( 'mzx-footer-col-3' ) ) {
			return;
		}

		$mzx_footer_widgets_style = apply_filters( 'mzx_footer_widgets_style', get_theme_mod( 'magazinex_footer_column_layout', 'mzx-grid-cols--3' ) );

		$footer_sidebar_classes = apply_filters(
			'mzx_footer_sidebar_filter',
			array(
				'mzx-grid-cols--1' => array(
					'mzx-footer-col--1',
				),
				'mzx-grid-cols--2' => array(
					'mzx-footer-col--1',
					'mzx-footer-col--2',
				),
				'mzx-grid-cols--3' => array(
					'mzx-footer-col--1',
					'mzx-footer-col--2',
					'mzx-footer-col--3',
				),
			)
		);
		?>
		<div class="mzx-footer-cols">
			<div class="mzx-container <?php mzx_footer_widget_container_class(); ?>">
				<?php
				foreach ( $footer_sidebar_classes as $footer_sidebar_key => $footer_sidebar_class ) {
					foreach ( $footer_sidebar_class as $footer_sidebar_display ) {

						if ( $footer_sidebar_key === $mzx_footer_widgets_style ) {
							?>
							<div class="mzx-footer-col <?php echo esc_attr( $footer_sidebar_display ); ?>">
								<?php if ( is_active_sidebar( $footer_sidebar_display ) ) : ?>
									<?php dynamic_sidebar( $footer_sidebar_display ); ?>
								<?php endif; ?>
							</div>
							<?php
						}
					}
				}
				?>
			</div>
		</div><!-- .mzx-footer-cols -->
		<?php
	}

	add_action( 'magazinex_footer_columns', 'magazinex_footer_columns_markup' );
}

if ( ! function_exists( 'magazinex_footer_bar_markup' ) ) {

	/**
	 * Adds MagazineX bar markup.
	 *
	 * @return void
	 */
	function magazinex_footer_bar_markup() {
		?>
		<div class="mzx-footer-bar">
			<div class="mzx-container">
				<?php magazinex_footer_bar_1(); ?>
				<?php magazinex_footer_bar_2(); ?>
			</div>
		</div><!-- .mzx-footer-bar -->
		<?php
	}

	add_action( 'magazinex_footer_bar', 'magazinex_footer_bar_markup' );
}

if ( ! function_exists( 'magazinex_footer_bar_1_markup' ) ) {
	/**
	 * Markup for footer copyright.
	 *
	 * @return void
	 * @since  1.0.0
	 */
	function magazinex_footer_bar_1_markup() {
		$default = sprintf(
		/* translators: 1: Copyright, 2: Current year, 3: Site title, 4: Theme credit */
			esc_html__( '%1$s %2$s %3$s, %4$s. %5$s.', 'magazinex' ),
			'{text}',
			'{copyright}',
			'{year}',
			'{site-link}',
			'{theme-credit}'
		);
		$content      = $default;
		$text         = esc_html__( 'Copyright ', 'magazinex' );
		$site_link    = '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" >' . get_bloginfo( 'name', 'display' ) . '</a>';
		$theme_credit = esc_html__( 'Built with ', 'magazinex' ) . '<a href="https://wpblockart.com/wordpress-themes/magazinex/" target="_blank"
							title="' . esc_attr__( 'MagazineX', 'magazinex' ) . '"
							rel="nofollow">' . esc_html__( 'MagazineX', 'magazinex' ) . '</a>';

		if ( $content || is_customize_preview() ) {
			$content = str_replace( '{text}', $text, $content );
			$content = str_replace( '{copyright}', '&copy;', $content );
			$content = str_replace( '{year}', date_i18n( 'Y' ), $content );
			$content = str_replace( '{site-link}', $site_link, $content );
			$content = str_replace( '{theme-credit}', $theme_credit, $content );
		}
		?>
		<div class="mzx-footer-bar-1">
			<?php echo do_shortcode( wp_kses_post( $content ) ); ?>
		</div><!-- .mzx-footer-bar-1 -->
		<?php
	}

	add_action( 'magazinex_footer_bar_1', 'magazinex_footer_bar_1_markup' );
}

if ( ! function_exists( 'magazinex_footer_bar_2_markup' ) ) {
	/**
	 * Markup for footer copyright.
	 *
	 * @return void
	 * @since  1.0.0
	 */
	function magazinex_footer_bar_2_markup() {
		?>
		<div class="mzx-footer-bar-2">
			<?php
			if ( has_nav_menu( 'mzx-menu-footer' ) ) {
				wp_nav_menu(
					array(
						'theme_location' => 'mzx-menu-footer',
						'menu_class'     => 'mzx-toggle-menu',
						'menu_id'        => 'toggle-menu',
						'container'      => '',
					)
				);
			}
			?>
		</div><!-- .mzx-footer-bar-2 -->
		<?php
	}

	add_action( 'magazinex_footer_bar_2', 'magazinex_footer_bar_2_markup' );
}

